@@ -64,12 +64,9 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study, decr
 
         # decryption
         unzip_file_path = uncompress(csv_path, decryption_password)
+        print(unzip_file_path)
+        df_day = pd.read_csv(unzip_file_path)
 
-        try:
-            df_day = pd.read_csv(unzip_file_path)
-        except pd.errors.EmptyDataError:
-            print("pandas.errors.EmptyDataError (location) : " + unzip_file_path)
-            quit()
 
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
